@@ -2,6 +2,7 @@
 """Functions for working with encapsulated (compressed) pixel data."""
 
 from struct import pack
+import warnings
 
 import pydicom.config
 from pydicom.filebase import DicomBytesIO
@@ -42,17 +43,22 @@ def get_frame_offsets(fp):
     All decoders, both for single and multi-frame images should accept both
     an empty Basic Offset Table and one containing offset values.
 
+    .. versionchanged:: 1.4
+
+        Changed to return (is BOT empty, list of offsets).
+
     Parameters
     ----------
-    fp : pydicom.filebase.DicomBytesIO
+    fp : filebase.DicomBytesIO
         The encapsulated pixel data positioned at the start of the Basic Offset
-        Table. ``fp.is_little_endian`` should be set to True.
+        Table. ``fp.is_little_endian`` should be set to ``True``.
 
     Returns
     -------
-    list of int
-        The byte offsets to the first fragment of each frame, as measured from
-        the start of the first item following the Basic Offset Table item.
+    bool, list of int
+        Whether or not the BOT is empty, and a list of the byte offsets
+        to the first fragment of each frame, as measured from the start of the
+        first item following the Basic Offset Table item.
 
     Raises
     ------
@@ -62,7 +68,7 @@ def get_frame_offsets(fp):
 
     References
     ----------
-    DICOM Standard Part 5, Annex A.4
+    DICOM Standard, Part 5, :dcm:`Annex A.4 <part05/sect_A.4.html>`
     """
     if not fp.is_little_endian:
         raise ValueError("'fp.is_little_endian' must be True")
@@ -86,21 +92,58 @@ def get_frame_offsets(fp):
     for ii in range(length // 4):
         offsets.append(fp.read_UL())
 
-    return offsets
+    return bool(length), offsets
+
+
+def get_nr_fragments(fp):
+    """Return the number of fragments in `fp`.
+
+    .. versionadded:: 1.4
+    """
+    if not fp.is_little_endian:
+        raise ValueError("'fp.is_little_endian' must be True")
+
+    nr_fragments = 0
+    start = fp.tell()
+    while True:
+        try:
+            tag = Tag(fp.read_tag())
+        except EOFError:
+            break
+
+        if tag == 0xFFFEE000:
+            # Item
+            length = fp.read_UL()
+            if length == 0xFFFFFFFF:
+                raise ValueError("Undefined item length at offset {} when "
+                                 "parsing the encapsulated pixel data "
+                                 "fragments.".format(fp.tell() - 4))
+            fp.seek(length, 1)
+            nr_fragments += 1
+        elif tag == 0xFFFEE0DD:
+            # Sequence Delimiter
+            break
+        else:
+            raise ValueError("Unexpected tag '{}' at offset {} when parsing "
+                             "the encapsulated pixel data fragment items."
+                             .format(tag, fp.tell() - 4))
+
+    fp.seek(start)
+    return nr_fragments
 
 
 def generate_pixel_data_fragment(fp):
-    """Yield the encapsulated pixel data fragments as bytes.
+    """Yield the encapsulated pixel data fragments.
 
-    For compressed (encapsulated) Transfer Syntaxes, the (7fe0,0010) 'Pixel
-    Data' element is encoded in an encapsulated format.
+    For compressed (encapsulated) Transfer Syntaxes, the (7FE0,0010) *Pixel
+    Data* element is encoded in an encapsulated format.
 
     **Encapsulation**
 
     The encoded pixel data stream is fragmented into one or more Items. The
     stream may represent a single or multi-frame image.
 
-    Each *Data Stream Fragment* shall have tag of (fffe,e000), followed by a 4
+    Each *Data Stream Fragment* shall have tag of (FFFE,E000), followed by a 4
     byte *Item Length* field encoding the explicit number of bytes in the Item.
     All Items containing an encoded fragment shall have an even number of bytes
     greater than or equal to 2, with the last fragment being padded if
@@ -109,26 +152,26 @@ def generate_pixel_data_fragment(fp):
     The first Item in the Sequence of Items shall be a 'Basic Offset Table',
     however the Basic Offset Table item value is not required to be present.
     It is assumed that the Basic Offset Table item has already been read prior
-    to calling this function (and that ``fp`` is positioned past this item).
+    to calling this function (and that `fp` is positioned past this item).
 
     The remaining items in the Sequence of Items are the pixel data fragments
     and it is these items that will be read and returned by this function.
 
-    The Sequence of Items is terminated by a Sequence Delimiter Item with tag
-    (fffe,e0dd) and an Item Length field of value ``0x00000000``. The presence
-    or absence of the Sequence Delimiter Item in `fp` has no effect on the
+    The Sequence of Items is terminated by a (FFFE,E0DD) *Sequence Delimiter
+    Item* with an Item Length field of value ``0x00000000``. The presence
+    or absence of the *Sequence Delimiter Item* in `fp` has no effect on the
     returned fragments.
 
-    Encoding
-    ~~~~~~~~
+    *Encoding*
+
     The encoding of the data shall be little endian.
 
     Parameters
     ----------
-    fp : pydicom.filebase.DicomBytesIO
-        The encoded (7fe0,0010) *Pixel Data* element value, positioned at the
+    fp : filebase.DicomBytesIO
+        The encoded (7FE0,0010) *Pixel Data* element value, positioned at the
         start of the item tag for the first item after the Basic Offset Table
-        item. ``fp.is_little_endian`` should be set to True.
+        item. ``fp.is_little_endian`` should be set to ``True``.
 
     Yields
     ------
@@ -143,7 +186,7 @@ def generate_pixel_data_fragment(fp):
 
     References
     ----------
-    DICOM Standard Part 5, Annex A.4
+    DICOM Standard Part 5, :dcm:`Annex A.4 <part05/sect_A.4.html>`
     """
     if not fp.is_little_endian:
         raise ValueError("'fp.is_little_endian' must be True")
@@ -175,15 +218,19 @@ def generate_pixel_data_fragment(fp):
                              .format(tag, fp.tell() - 4))
 
 
-def generate_pixel_data_frame(bytestream):
-    """Yield an encapsulated pixel data frame as bytes.
+def generate_pixel_data_frame(bytestream, nr_frames=None):
+    """Yield an encapsulated pixel data frame.
 
     Parameters
     ----------
     bytestream : bytes
-        The value of the (7fe0, 0010) *Pixel Data* element from an encapsulated
+        The value of the (7FE0,0010) *Pixel Data* element from an encapsulated
         dataset. The Basic Offset Table item should be present and the
         Sequence Delimiter item may or may not be present.
+    nr_frames : int, optional
+        Required for multi-frame data when the Basic Offset Table is empty
+        and there are multiple frames. This should be the value of (0028,0008)
+        *Number of Frames*.
 
     Yields
     ------
@@ -192,14 +239,14 @@ def generate_pixel_data_frame(bytestream):
 
     References
     ----------
-    DICOM Standard Part 5, Annex A
+    DICOM Standard Part 5, :dcm:`Annex A <part05/chapter_A.html>`
     """
-    for fragmented_frame in generate_pixel_data(bytestream):
+    for fragmented_frame in generate_pixel_data(bytestream, nr_frames):
         yield b''.join(fragmented_frame)
 
 
-def generate_pixel_data(bytestream):
-    """Yield an encapsulated pixel data frame as a tuples of bytes.
+def generate_pixel_data(bytestream, nr_frames=None):
+    """Yield an encapsulated pixel data frame.
 
     For the following transfer syntaxes, a fragment may not contain encoded
     data from more than one frame. However data from one frame may span
@@ -227,46 +274,120 @@ def generate_pixel_data(bytestream):
     Parameters
     ----------
     bytestream : bytes
-        The value of the (7fe0, 0010) *Pixel Data* element from an encapsulated
+        The value of the (7FE0,0010) *Pixel Data* element from an encapsulated
         dataset. The Basic Offset Table item should be present and the
         Sequence Delimiter item may or may not be present.
+    nr_frames : int, optional
+        Required for multi-frame data when the Basic Offset Table is empty
+        and there are multiple frames. This should be the value of (0028,0008)
+        *Number of Frames*.
 
     Yields
     -------
     tuple of bytes
-        A tuple representing an encapsulated pixel data frame, with the
-        contents of the tuple the frame's fragmented data.
+        An encapsulated pixel data frame, with the contents of the
+        :class:`tuple` the frame's fragmented data.
+
+    Notes
+    -----
+    If the Basic Offset Table is empty and there are multiple fragments per
+    frame then an attempt will be made to locate the frame boundaries by
+    searching for the JPEG/JPEG-LS/JPEG2000 EOI/EOC marker (``0xFFD9``). If the
+    marker is not present or the pixel data hasn't been compressed using one of
+    the JPEG standards then the generated pixel data may be incorrect.
 
     References
     ----------
-    DICOM Standard Part 5, Annex A
+    DICOM Standard Part 5, :dcm:`Annex A <part05/chapter_A.html>`
     """
     fp = DicomBytesIO(bytestream)
     fp.is_little_endian = True
 
     # `offsets` is a list of the offsets to the first fragment in each frame
-    offsets = get_frame_offsets(fp)
+    has_bot, offsets = get_frame_offsets(fp)
     # Doesn't actually matter what the last offset value is, as long as its
     # greater than the total number of bytes in the fragments
     offsets.append(len(bytestream))
 
-    frame = []
-    frame_length = 0
-    frame_number = 0
-    for fragment in generate_pixel_data_fragment(fp):
-        if frame_length < offsets[frame_number + 1]:
-            frame.append(fragment)
+    if has_bot:
+        # Use the BOT to determine the frame boundaries
+        frame = []
+        frame_length = 0
+        frame_number = 0
+        for fragment in generate_pixel_data_fragment(fp):
+            if frame_length < offsets[frame_number + 1]:
+                frame.append(fragment)
+            else:
+                yield tuple(frame)
+                frame = [fragment]
+                frame_number += 1
+
+            frame_length += len(fragment) + 8
+
+        # Yield the final frame - required here because the frame_length will
+        # never be greater than offsets[-1] and thus never trigger the final
+        # yield within the for block
+        yield tuple(frame)
+    else:
+        nr_fragments = get_nr_fragments(fp)
+        if nr_fragments == 1:
+            # Single fragment: 1 frame
+            for fragment in generate_pixel_data_fragment(fp):
+                yield tuple([fragment])
+        elif nr_frames:
+            # Multiple fragments: 1 or more frames
+            if nr_fragments == nr_frames:
+                # 1 fragment per frame
+                # Covers RLE and others if 1:1 ratio
+                for fragment in generate_pixel_data_fragment(fp):
+                    yield tuple([fragment])
+            elif nr_frames == 1:
+                # Multiple fragments: 1 frame
+                frame = []
+                for fragment in generate_pixel_data_fragment(fp):
+                    frame.append(fragment)
+                yield tuple(frame)
+            elif nr_fragments > nr_frames:
+                # More fragments then frames
+                # Search for JPEG/JPEG-LS/JPEG2K EOI/EOC marker
+                # Should be the last two bytes of a frame
+                # May fail if no EOI/EOC marker or not JPEG
+                eoi_marker = b'\xff\xd9'
+                frame = []
+                frame_nr = 0
+                for fragment in generate_pixel_data_fragment(fp):
+                    frame.append(fragment)
+                    if eoi_marker in fragment[-10:]:
+                        yield tuple(frame)
+                        frame_nr += 1
+                        frame = []
+
+                if frame or frame_nr != nr_frames:
+                    # If data in `frame` or fewer frames yielded then we
+                    #   must've missed a frame boundary
+                    warnings.warn(
+                        "The end of the encapsulated pixel data has been "
+                        "reached but one or more frame boundaries may have "
+                        "been missed; please confirm that the generated frame "
+                        "data is correct"
+                    )
+                    if frame:
+                        yield tuple(frame)
+
+            else:
+                # Fewer fragments than frames
+                raise ValueError(
+                    "Unable to parse encapsulated pixel data as the Basic "
+                    "Offset Table is empty and there are fewer fragments then "
+                    "frames; the dataset may be corrupt"
+                )
         else:
-            yield tuple(frame)
-            frame = [fragment]
-            frame_number += 1
-
-        frame_length += len(fragment) + 8
-
-    # Yield the final frame - required here because the frame_length will
-    # never be greater than offsets[-1] and thus never trigger the final yield
-    # within the for block
-    yield tuple(frame)
+            # Multiple fragments but unknown number of frames
+            raise ValueError(
+                "Unable to determine the frame boundaries for the "
+                "encapsulated pixel data as the Basic Offset Table is empty "
+                "and `nr_frames` parameter is None"
+            )
 
 
 def decode_data_sequence(data):
@@ -274,13 +395,13 @@ def decode_data_sequence(data):
 
     Parameters
     ----------
-    data : str
-        String of encapsulated data, typically dataset.PixelData
+    data : bytes or str
+        The encapsulated data, typically the value from ``Dataset.PixelData``.
 
     Returns
     -------
     list of bytes
-        All fragments in a list of byte strings
+        All fragments as a list of ``bytes``.
     """
     # Convert data into a memory-mapped file
     with DicomBytesIO(data) as fp:
@@ -303,7 +424,7 @@ def decode_data_sequence(data):
 
 
 def defragment_data(data):
-    """Read encapsulated data and return the fragments as one continuous string.
+    """Read encapsulated data and return the fragments as one continuous bytes.
 
     Parameters
     ----------
@@ -324,13 +445,13 @@ def read_item(fp):
 
     Parameters
     ----------
-    fp : pydicom.filebase.DicomIO
+    fp : filebase.DicomIO
         The file-like to read the item from.
 
     Returns
     -------
     bytes
-        The Item's raw bytes (value?).
+        The Item's raw bytes.
     """
 
     logger = pydicom.config.logger
@@ -384,12 +505,14 @@ def read_item(fp):
 def fragment_frame(frame, nr_fragments=1):
     """Yield one or more fragments from `frame`.
 
+    .. versionadded:: 1.2
+
     Parameters
     ----------
     frame : bytes
         The data to fragment.
     nr_fragments : int, optional
-        The number of fragments (default 1).
+        The number of fragments (default ``1``).
 
     Yields
     ------
@@ -407,11 +530,12 @@ def fragment_frame(frame, nr_fragments=1):
     * Any necessary padding may be appended after the end of image marker.
     * Encapsulated Pixel Data has the Value Representation OB.
     * Values with a VR of OB shall be padded with a single trailing NULL byte
-      value (0x00) to achieve even length.
+      value (``0x00``) to achieve even length.
 
     References
     ----------
-    DICOM Standard, Part 5, Section 6.2 and Annex A.4
+    DICOM Standard, Part 5, :dcm:`Section 6.2 <part05/sect_6.2.html>` and
+    :dcm:`Annex A.4 <part05/sect_A.4.html>`
     """
     frame_length = len(frame)
     # Add 1 to fix odd length frames not being caught
@@ -443,6 +567,8 @@ def fragment_frame(frame, nr_fragments=1):
 def itemise_fragment(fragment):
     """Return an itemised `fragment`.
 
+    .. versionadded:: 1.2
+
     Parameters
     ----------
     fragment : bytes
@@ -476,6 +602,8 @@ itemize_fragment = itemise_fragment
 def itemise_frame(frame, nr_fragments=1):
     """Yield items generated from `frame`.
 
+    .. versionadded:: 1.2
+
     Parameters
     ----------
     frame : bytes
@@ -497,7 +625,8 @@ def itemise_frame(frame, nr_fragments=1):
 
     References
     ----------
-    DICOM Standard, Part 5, Section 7.5 and Annex A.4
+    DICOM Standard, Part 5, :dcm:`Section 7.5 <part05/sect_7.5.html>` and
+    :dcm:`Annex A.4 <part05/sect_A.4.html>`
     """
     for fragment in fragment_frame(frame, nr_fragments):
         yield itemise_fragment(fragment)
@@ -509,43 +638,43 @@ itemize_frame = itemise_frame
 def encapsulate(frames, fragments_per_frame=1, has_bot=True):
     """Return encapsulated `frames`.
 
+    .. versionadded:: 1.2
+
+    When using a compressed transfer syntax (such as RLE Lossless or one of
+    JPEG formats) then any *Pixel Data* must be :dcm:`encapsulated
+    <part05/sect_A.4.html>`::
+
+      # Where `frame1`, `frame2` are single frames that have been encoded
+      # using the corresponding compression method to Transfer Syntax UID
+      ds.PixelData = encapsulate([frame1, frame2, ...])
+
+    For multi-frame data each frame must be encoded separately and then all
+    encoded frames encapsulated together.
+
     Data will be encapsulated with a Basic Offset Table Item at the beginning,
-    then one or more fragment Items. Each item will be of even length and the
-    final fragment of each frame may be padded with 0x00 if required.
+    then one or more fragment items. Each item will be of even length and the
+    final fragment of each frame may be padded with ``0x00`` if required.
 
     Parameters
     ----------
     frames : list of bytes
-        The frame data to encapsulate.
+        The frame data to encapsulate, one frame per item.
     fragments_per_frame : int, optional
-        The number of fragments to use for each frame (default 1).
+        The number of fragments to use for each frame (default ``1``).
     has_bot : bool, optional
-        True to include values in the Basic Offset Table, False otherwise
-        (default True). If `fragments_per_frame` is not 1 then its strongly
-        recommended that this be True.
+        ``True`` to include values in the Basic Offset Table, ``False``
+        otherwise (default ``True``). If `fragments_per_frame` is not ``1``
+        then it's strongly recommended that this be ``True``.
 
     Returns
     -------
     bytes
-        The encapsulated data.
-
-    Notes
-    -----
-
-    * The encoding shall be in Little Endian.
-    * Each fragment is encapsulated as a DICOM Item with tag (FFFE,E000), then
-      a 4 byte length.
-    * The first item shall be a Basic Offset Table item.
-    * The Basic Offset Table item, however, is not required to have a value.
-    * If no value is present, the Basic Offset Table length is 0.
-    * If the value is present, it shall contain concatenated 32-bit
-      unsigned integer values that are byte offsets to the first byte of the
-      Item tag of the first fragment in each frame as measured from the first
-      byte of the first Item tag following the Basic Offset Table Item.
+        The encapsulated pixel data.
 
     References
     ----------
-    DICOM Standard, Part 5, Section 7.5 and Annex A.4
+    DICOM Standard, Part 5, :dcm:`Section 7.5 <part05/sect_7.5.html>` and
+    :dcm:`Annex A.4 <part05/sect_A.4.html>`
     """
     no_frames = len(frames)
     output = bytearray()
