@@ -1,27 +1,32 @@
 # Copyright 2008-2018 pydicom authors. See LICENSE file for details.
 """Functions related to writing DICOM data."""
 
-from __future__ import absolute_import
 
 import warnings
+import zlib
 from struct import pack
 
-from pydicom import compat
-from pydicom.compat import in_py2
 from pydicom.charset import (
     default_encoding, text_VRs, convert_encodings, encode_string
 )
+from pydicom.config import have_numpy
 from pydicom.dataelem import DataElement_from_raw
 from pydicom.dataset import Dataset, validate_file_meta
 from pydicom.filebase import DicomFile, DicomFileLike, DicomBytesIO
+from pydicom.fileutil import path_from_pathlike
 from pydicom.multival import MultiValue
 from pydicom.tag import (Tag, ItemTag, ItemDelimiterTag, SequenceDelimiterTag,
                          tag_in_exception)
-from pydicom.uid import UncompressedPixelTransferSyntaxes
-from pydicom.valuerep import extra_length_VRs, PersonNameUnicode
+from pydicom.uid import (UncompressedPixelTransferSyntaxes,
+                         DeflatedExplicitVRLittleEndian)
+from pydicom.valuerep import extra_length_VRs
 from pydicom.values import convert_numbers
 
 
+if have_numpy:
+    import numpy
+
+
 def _correct_ambiguous_vr_element(elem, ds, is_little_endian):
     """Implementation for `correct_ambiguous_vr_element`.
     See `correct_ambiguous_vr_element` for description.
@@ -259,6 +264,8 @@ def write_UI(fp, data_element):
 
 def _is_multi_value(val):
     """Return True if `val` is a multi-value container."""
+    if have_numpy and isinstance(val, numpy.ndarray):
+        return True
     return isinstance(val, (MultiValue, list, tuple))
 
 
@@ -279,14 +286,7 @@ def write_PN(fp, data_element, encodings=None):
     else:
         val = data_element.value
 
-    if val and isinstance(val[0], compat.text_type) or not in_py2:
-        try:
-            val = [elem.encode(encodings) for elem in val]
-        except TypeError:
-            # we get here in Python 2 if val is a unicode string
-            val = [PersonNameUnicode(elem, encodings) for elem in val]
-            val = [elem.encode(encodings) for elem in val]
-
+    val = [elem.encode(encodings) for elem in val]
     val = b'\\'.join(val)
 
     if len(val) % 2 != 0:
@@ -301,7 +301,7 @@ def write_string(fp, data_element, padding=' '):
     if val is not None:
         if len(val) % 2 != 0:
             val = val + padding  # pad to even length
-        if isinstance(val, compat.text_type):
+        if isinstance(val, str):
             val = val.encode(default_encoding)
         fp.write(val)
 
@@ -312,13 +312,13 @@ def write_text(fp, data_element, encodings=None):
     if val is not None:
         encodings = encodings or [default_encoding]
         if _is_multi_value(val):
-            if val and isinstance(val[0], compat.text_type):
+            if val and isinstance(val[0], str):
                 val = b'\\'.join([encode_string(val, encodings)
                                   for val in val])
             else:
                 val = b'\\'.join([val for val in val])
         else:
-            if isinstance(val, compat.text_type):
+            if isinstance(val, str):
                 val = encode_string(val, encodings)
 
         if len(val) % 2 != 0:
@@ -335,8 +335,8 @@ def write_number_string(fp, data_element):
 
     if _is_multi_value(val):
         val = "\\".join((x.original_string
-                         if hasattr(x, 'original_string') else str(x)
-                         for x in val))
+                         if hasattr(x, 'original_string')
+                         else str(x) for x in val))
     else:
         if hasattr(val, 'original_string'):
             val = val.original_string
@@ -346,8 +346,7 @@ def write_number_string(fp, data_element):
     if len(val) % 2 != 0:
         val = val + ' '  # pad to even length
 
-    if not in_py2:
-        val = bytes(val, default_encoding)
+    val = bytes(val, default_encoding)
 
     fp.write(val)
 
@@ -363,18 +362,18 @@ def _format_DA(val):
 
 def write_DA(fp, data_element):
     val = data_element.value
-    if isinstance(val, (str, compat.string_types)):
+    if isinstance(val, str):
         write_string(fp, data_element)
     else:
         if _is_multi_value(val):
-            val = "\\".join((x if isinstance(x, (str, compat.string_types))
+            val = "\\".join((x if isinstance(x, str)
                              else _format_DA(x) for x in val))
         else:
             val = _format_DA(val)
         if len(val) % 2 != 0:
             val = val + ' '  # pad to even length
 
-        if isinstance(val, compat.string_types):
+        if isinstance(val, str):
             val = val.encode(default_encoding)
 
         fp.write(val)
@@ -391,18 +390,18 @@ def _format_DT(val):
 
 def write_DT(fp, data_element):
     val = data_element.value
-    if isinstance(val, (str, compat.string_types)):
+    if isinstance(val, str):
         write_string(fp, data_element)
     else:
         if _is_multi_value(val):
-            val = "\\".join((x if isinstance(x, (str, compat.string_types))
+            val = "\\".join((x if isinstance(x, str)
                              else _format_DT(x) for x in val))
         else:
             val = _format_DT(val)
         if len(val) % 2 != 0:
             val = val + ' '  # pad to even length
 
-        if isinstance(val, compat.string_types):
+        if isinstance(val, str):
             val = val.encode(default_encoding)
 
         fp.write(val)
@@ -421,18 +420,18 @@ def _format_TM(val):
 
 def write_TM(fp, data_element):
     val = data_element.value
-    if isinstance(val, (str, compat.string_types)):
+    if isinstance(val, str):
         write_string(fp, data_element)
     else:
         if _is_multi_value(val):
-            val = "\\".join((x if isinstance(x, (str, compat.string_types))
+            val = "\\".join((x if isinstance(x, str)
                              else _format_TM(x) for x in val))
         else:
             val = _format_TM(val)
         if len(val) % 2 != 0:
             val = val + ' '  # pad to even length
 
-        if isinstance(val, compat.string_types):
+        if isinstance(val, str):
             val = val.encode(default_encoding)
 
         fp.write(val)
@@ -512,10 +511,8 @@ def write_data_element(fp, data_element, encodings=None):
 
     # write the VR for explicit transfer syntax
     if not fp.is_implicit_VR:
-        if not in_py2:
-            fp.write(bytes(VR, default_encoding))
-        else:
-            fp.write(VR)
+        fp.write(bytes(VR, default_encoding))
+
         if VR in extra_length_VRs:
             fp.write_US(0)  # reserved 2 bytes
 
@@ -739,6 +736,42 @@ def write_file_meta_info(fp, file_meta, enforce_standard=True):
     fp.write(buffer.getvalue())
 
 
+def _write_dataset(fp, dataset, write_like_original):
+    """Write the Data Set to a file-like. Assumes the file meta information,
+    if any, has been written.
+    """
+
+    # if we want to write with the same endianess and VR handling as
+    # the read dataset we want to preserve raw data elements for
+    # performance reasons (which is done by get_item);
+    # otherwise we use the default converting item getter
+    if dataset.is_original_encoding:
+        get_item = Dataset.get_item
+    else:
+        get_item = Dataset.__getitem__
+
+    # WRITE DATASET
+    # The transfer syntax used to encode the dataset can't be changed
+    #   within the dataset.
+    # Write any Command Set elements now as elements must be in tag order
+    #   Mixing Command Set with other elements is non-conformant so we
+    #   require `write_like_original` to be True
+    command_set = get_item(dataset, slice(0x00000000, 0x00010000))
+    if command_set and write_like_original:
+        fp.is_implicit_VR = True
+        fp.is_little_endian = True
+        write_dataset(fp, command_set)
+
+    # Set file VR and endianness. MUST BE AFTER writing META INFO (which
+    #   requires Explicit VR Little Endian) and COMMAND SET (which requires
+    #   Implicit VR Little Endian)
+    fp.is_implicit_VR = dataset.is_implicit_VR
+    fp.is_little_endian = dataset.is_little_endian
+
+    # Write non-Command Set elements now
+    write_dataset(fp, get_item(dataset, slice(0x00010000, None)))
+
+
 def dcmwrite(filename, dataset, write_like_original=True):
     """Write `dataset` to the `filename` specified.
 
@@ -748,9 +781,16 @@ def dcmwrite(filename, dataset, write_like_original=True):
     the DICOM File Format).
 
     If `write_like_original` is ``False``, `dataset` will be stored in the
-    :dcm:`DICOM File Format <part10/chapter_7.html>`. The
-    byte stream of the `dataset` will be placed into the file after the
-    DICOM *File Meta Information*.
+    :dcm:`DICOM File Format <part10/chapter_7.html>`.  To do
+    so requires that the ``Dataset.file_meta`` attribute
+    exists and contains a :class:`Dataset` with the required (Type 1) *File
+    Meta Information Group* elements. The byte stream of the `dataset` will be
+    placed into the file after the DICOM *File Meta Information*.
+
+    If `write_like_original` is ``True`` then the :class:`Dataset` will be
+    written as is (after minimal validation checking) and may or may not
+    contain all or parts of the *File Meta Information* (and hence may or
+    may not be conformant with the DICOM File Format).
 
     **File Meta Information**
 
@@ -823,7 +863,7 @@ def dcmwrite(filename, dataset, write_like_original=True):
 
     Parameters
     ----------
-    filename : str or file-like
+    filename : str or PathLike or file-like
         Name of file or the file-like to write the new DICOM file to.
     dataset : pydicom.dataset.FileDataset
         Dataset holding the DICOM information; e.g. an object read with
@@ -848,14 +888,53 @@ def dcmwrite(filename, dataset, write_like_original=True):
         If ``False``, produces a file conformant with the DICOM File Format,
         with explicit lengths for all elements.
 
+    Raises
+    ------
+    AttributeError
+        If either ``dataset.is_implicit_VR`` or ``dataset.is_little_endian``
+        have not been set.
+    ValueError
+        If group 2 elements are in ``dataset`` rather than
+        ``dataset.file_meta``, or if a preamble is given but is not 128 bytes
+        long, or if Transfer Syntax is a compressed type and pixel data is not
+        compressed.
+
     See Also
     --------
-    pydicom.dataset.FileDataset
+    pydicom.dataset.Dataset
         Dataset class with relevant attributes and information.
     pydicom.dataset.Dataset.save_as
         Write a DICOM file from a dataset that was read in with ``dcmread()``.
         ``save_as()`` wraps ``dcmwrite()``.
     """
+
+    # Ensure is_little_endian and is_implicit_VR are set
+    if None in (dataset.is_little_endian, dataset.is_implicit_VR):
+        has_tsyntax = False
+        try:
+            tsyntax = dataset.file_meta.TransferSyntaxUID
+            if not tsyntax.is_private:
+                dataset.is_little_endian = tsyntax.is_little_endian
+                dataset.is_implicit_VR = tsyntax.is_implicit_VR
+                has_tsyntax = True
+        except AttributeError:
+            pass
+
+        if not has_tsyntax:
+            raise AttributeError(
+                "'{0}.is_little_endian' and '{0}.is_implicit_VR' must be "
+                "set appropriately before saving."
+                .format(dataset.__class__.__name__)
+            )
+
+    # Try and ensure that `is_undefined_length` is set correctly
+    try:
+        tsyntax = dataset.file_meta.TransferSyntaxUID
+        if not tsyntax.is_private:
+            dataset['PixelData'].is_undefined_length = tsyntax.is_compressed
+    except (AttributeError, KeyError):
+        pass
+
     # Check that dataset's group 0x0002 elements are only present in the
     #   `dataset.file_meta` Dataset - user may have added them to the wrong
     #   place
@@ -896,22 +975,14 @@ def dcmwrite(filename, dataset, write_like_original=True):
 
     caller_owns_file = True
     # Open file if not already a file object
-    if isinstance(filename, compat.string_types):
+    filename = path_from_pathlike(filename)
+    if isinstance(filename, str):
         fp = DicomFile(filename, 'wb')
         # caller provided a file name; we own the file handle
         caller_owns_file = False
     else:
         fp = DicomFileLike(filename)
 
-    # if we want to write with the same endianess and VR handling as
-    # the read dataset we want to preserve raw data elements for
-    # performance reasons (which is done by get_item);
-    # otherwise we use the default converting item getter
-    if dataset.is_original_encoding:
-        get_item = Dataset.get_item
-    else:
-        get_item = Dataset.__getitem__
-
     try:
         # WRITE FILE META INFORMATION
         if preamble:
@@ -919,31 +990,32 @@ def dcmwrite(filename, dataset, write_like_original=True):
             fp.write(preamble)
             fp.write(b'DICM')
 
+        tsyntax = None
         if dataset.file_meta:  # May be an empty Dataset
             # If we want to `write_like_original`, don't enforce_standard
             write_file_meta_info(fp, dataset.file_meta,
                                  enforce_standard=not write_like_original)
+            tsyntax = getattr(dataset.file_meta, "TransferSyntaxUID", None)
 
-        # WRITE DATASET
-        # The transfer syntax used to encode the dataset can't be changed
-        #   within the dataset.
-        # Write any Command Set elements now as elements must be in tag order
-        #   Mixing Command Set with other elements is non-conformant so we
-        #   require `write_like_original` to be True
-        command_set = get_item(dataset, slice(0x00000000, 0x00010000))
-        if command_set and write_like_original:
-            fp.is_implicit_VR = True
-            fp.is_little_endian = True
-            write_dataset(fp, command_set)
+        if (tsyntax == DeflatedExplicitVRLittleEndian):
+            # See PS3.5 section A.5
+            # when writing, the entire dataset following
+            #     the file metadata is prepared the normal way,
+            #     then "deflate" compression applied.
+            buffer = DicomBytesIO()
+            _write_dataset(buffer, dataset, write_like_original)
 
-        # Set file VR and endianness. MUST BE AFTER writing META INFO (which
-        #   requires Explicit VR Little Endian) and COMMAND SET (which requires
-        #   Implicit VR Little Endian)
-        fp.is_implicit_VR = dataset.is_implicit_VR
-        fp.is_little_endian = dataset.is_little_endian
+            # Compress the encoded data and write to file
+            compressor = zlib.compressobj(wbits=-zlib.MAX_WBITS)
+            deflated = compressor.compress(buffer.parent.getvalue())
+            deflated += compressor.flush()
+            if len(deflated) % 2:
+                deflated += b'\x00'
+
+            fp.write(deflated)
+        else:
+            _write_dataset(fp, dataset, write_like_original)
 
-        # Write non-Command Set elements now
-        write_dataset(fp, get_item(dataset, slice(0x00010000, None)))
     finally:
         if not caller_owns_file:
             fp.close()
@@ -969,7 +1041,7 @@ writers = {
     'LT': (write_text, None),
     'OB': (write_OBvalue, None),
     'OD': (write_OWvalue, None),
-    'OF': (write_numbers, 'f'),
+    'OF': (write_OWvalue, None),
     'OL': (write_OWvalue, None),
     'OW': (write_OWvalue, None),
     'OV': (write_OWvalue, None),
