@@ -2,7 +2,6 @@
 """Code for multi-value data elements values,
 or any list of items that must all be the same type.
 """
-from pydicom import compat
 
 try:
     from collections.abc import MutableSequence
@@ -49,13 +48,6 @@ class MultiValue(MutableSequence):
         for x in iterable:
             self._list.append(type_constructor(x))
 
-    # TODO: Workaround for #951, to be removed when Python 2 not supported
-    if compat.in_py2:
-        def __getstate__(self):
-            state = self.__dict__.copy()
-            del state['type_constructor']
-            return state
-
     def insert(self, position, val):
         self._list.insert(position, self.type_constructor(val))
 
@@ -73,7 +65,7 @@ class MultiValue(MutableSequence):
     def __str__(self):
         if not self:
             return ''
-        lines = ["'{}'".format(x) if isinstance(x, compat.char_types)
+        lines = ["'{}'".format(x) if isinstance(x, (str, bytes))
                  else str(x) for x in self]
         return "[" + ", ".join(lines) + "]"
 
