@@ -1,6 +1,5 @@
 # Copyright 2008-2018 pydicom authors. See LICENSE file for details.
 """Utility functions used in the pixel data handlers."""
-from __future__ import division
 
 from struct import unpack
 from sys import byteorder
@@ -113,6 +112,9 @@ def apply_color_lut(arr, ds=None, palette=None):
             "Table Module is not currently supported"
         )
 
+    if 'RedPaletteColorLookupTableDescriptor' not in ds:
+        raise ValueError("No suitable Palette Color Lookup Table Module found")
+
     # All channels are supposed to be identical
     lut_desc = ds.RedPaletteColorLookupTableDescriptor
     # A value of 0 = 2^16 entries
@@ -231,7 +233,15 @@ def apply_modality_lut(arr, ds):
         nominal_depth = item.LUTDescriptor[2]
 
         dtype = 'uint{}'.format(nominal_depth)
-        lut_data = np.asarray(item.LUTData, dtype=dtype)
+
+        # Ambiguous VR, US or OW
+        if item['LUTData'].VR == 'OW':
+            endianness = '<' if ds.is_little_endian else '>'
+            unpack_fmt = '{}{}H'.format(endianness, nr_entries)
+            lut_data = unpack(unpack_fmt, item.LUTData)
+        else:
+            lut_data = item.LUTData
+        lut_data = np.asarray(lut_data, dtype=dtype)
 
         # IVs < `first_map` get set to first LUT entry (i.e. index 0)
         clipped_iv = np.zeros(arr.shape, dtype=arr.dtype)
@@ -314,7 +324,14 @@ def apply_voi_lut(arr, ds, index=0):
                 .format(nominal_depth)
             )
 
-        lut_data = np.asarray(item.LUTData, dtype=dtype)
+        # Ambiguous VR, US or OW
+        if item['LUTData'].VR == 'OW':
+            endianness = '<' if ds.is_little_endian else '>'
+            unpack_fmt = '{}{}H'.format(endianness, nr_entries)
+            lut_data = unpack(unpack_fmt, item.LUTData)
+        else:
+            lut_data = item.LUTData
+        lut_data = np.asarray(lut_data, dtype=dtype)
 
         # IVs < `first_map` get set to first LUT entry (i.e. index 0)
         clipped_iv = np.zeros(arr.shape, dtype=arr.dtype)
