@@ -24,7 +24,7 @@ from pydicom.uid import UID
 from pydicom.valuerep import DSfloat
 
 
-class TestDataElement(object):
+class TestDataElement:
     """Tests for dataelem.DataElement."""
     def setup(self):
         self.data_elementSH = DataElement((1, 2), "SH", "hello")
@@ -104,7 +104,7 @@ class TestDataElement(object):
         assert 'Private tag data' == elem.description()
         elem = DataElement(0x00110F00, 'LO', 12345)
         assert elem.tag.is_private
-        assert not hasattr(elem, 'private_creator')
+        assert elem.private_creator is None
         assert 'Private tag data' == elem.description()
 
     def test_description_unknown(self):
@@ -281,28 +281,6 @@ class TestDataElement(object):
         elem[0].PatientID = '1234'
         assert repr(elem) == repr(elem.value)
 
-    @pytest.mark.skipif(sys.version_info >= (3,), reason='Python 2 behavior')
-    def test_unicode(self):
-        """Test unicode representation of the DataElement"""
-        elem = DataElement(0x00100010, 'PN', u'ANON')
-        # Make sure elem.value is actually unicode
-        assert isinstance(elem.value, unicode)
-        assert (
-                   u"(0010, 0010) Patient's Name                      PN: ANON"
-               ) == unicode(elem)
-        assert isinstance(unicode(elem), unicode)
-        assert not isinstance(unicode(elem), str)
-        # Make sure elem.value is still unicode
-        assert isinstance(elem.value, unicode)
-
-        # When value is not in compat.text_type
-        elem = DataElement(0x00100010, 'LO', 12345)
-        assert isinstance(unicode(elem), unicode)
-        assert (
-                   u"(0010, 0010) Patient's Name"
-                   u"                      LO: 12345"
-               ) == unicode(elem)
-
     def test_getitem_raises(self):
         """Test DataElement.__getitem__ raise if value not indexable"""
         elem = DataElement(0x00100010, 'LO', 12345)
@@ -533,7 +511,7 @@ class TestDataElement(object):
         assert elem.value == []
 
 
-class TestRawDataElement(object):
+class TestRawDataElement:
     """Tests for dataelem.RawDataElement."""
     def test_key_error(self):
         """RawDataElement: conversion of unknown tag throws KeyError..."""
