@@ -3,11 +3,10 @@
 
 import pytest
 
-from pydicom.compat import in_py2
 from pydicom.tag import BaseTag, Tag, TupleTag, tag_in_exception
 
 
-class TestBaseTag(object):
+class TestBaseTag:
     """Test the BaseTag class."""
     def test_le_same_class(self):
         """Test __le__ of two classes with same type."""
@@ -241,18 +240,8 @@ class TestBaseTag(object):
         assert BaseTag(0x000900FF).is_private_creator
         assert not BaseTag(0x00090100).is_private_creator
 
-    def test_base_class(self):
-        """Test the class BaseTag inherits from."""
-        if in_py2:
-            # Test for overflow of int
-            tag = Tag(0xFFFFFFFF)
-            assert isinstance(tag, long)
-        else:
-            tag = Tag(0xFFFFFFFF)
-            assert isinstance(tag, int)
 
-
-class TestTag(object):
+class TestTag:
     """Test the Tag method."""
     def test_tag_single_int(self):
         """Test creating a Tag from a single int."""
@@ -323,12 +312,6 @@ class TestTag(object):
         pytest.raises(ValueError, Tag, ['0x01', '0x02'], '0x01')
         pytest.raises(ValueError, Tag, ['0x01', '0x02'], 0x01)
 
-    @pytest.mark.skipif(not in_py2, reason='Long type only exists in Python 2')
-    def test_mixed_long_int(self):
-        assert Tag([0x1000, long(0x2000)]) == BaseTag(0x10002000)
-        assert Tag([long(0x1000), 0x2000]) == BaseTag(0x10002000)
-        assert Tag([long(0x1000), long(0x2000)]) == BaseTag(0x10002000)
-
     def test_tag_single_str(self):
         """Test creating a Tag from a single str."""
         assert Tag('0x10002000') == BaseTag(0x10002000)
@@ -380,14 +363,14 @@ class TestTag(object):
         pytest.raises(ValueError, Tag, -65535, -1)
 
 
-class TestTupleTag(object):
+class TestTupleTag:
     """Test the TupleTag method."""
     def test_tuple_tag(self):
         """Test quick tag construction with TupleTag."""
         assert TupleTag((0xFFFF, 0xFFee)) == BaseTag(0xFFFFFFEE)
 
 
-class TestTagInException(object):
+class TestTagInException:
     """Test the tag_in_exception method."""
     def test_raise_exception(self):
         """"""
