@@ -9,7 +9,7 @@ import pytest
 from pydicom import dcmread
 
 
-class TestUnicodeFilenames(object):
+class TestUnicodeFilenames:
     def test_read(self):
         """Unicode: Can read a file with unicode characters in name..."""
         uni_name = u'test°'
