@@ -3,8 +3,6 @@
 
 from binascii import (a2b_hex, b2a_hex)
 
-from pydicom import compat
-from pydicom.compat import in_py2
 from pydicom.charset import default_encoding
 
 
@@ -13,13 +11,18 @@ def hex2bytes(hexstring):
 
     This is useful for creating specific byte sequences for testing, using
     python's implied concatenation for strings with comments allowed.
-    Example:
+
+    Examples
+    --------
+
+    ::
         hex_string = (
-         "08 00 32 10"     # (0008, 1032) SQ "Procedure Code Sequence"
-         " 08 00 00 00"    # length 8
-         " fe ff 00 e0"    # (fffe, e000) Item Tag
+            "08 00 32 10 "  # (0008, 1032) SQ "Procedure Code Sequence"
+            "08 00 00 00 "  # length 8
+            "fe ff 00 e0 "  # (fffe, e000) Item Tag
         )
         byte_string = hex2bytes(hex_string)
+
     Note in the example that all lines except the first must
     start with a space, alternatively the space could
     end the previous line.
@@ -29,13 +32,12 @@ def hex2bytes(hexstring):
     # true in 2.x so the difference in bytes constructor doesn't matter
     if isinstance(hexstring, bytes):
         return a2b_hex(hexstring.replace(b" ", b""))
-    elif isinstance(hexstring, compat.string_types):
+    elif isinstance(hexstring, str):
         return a2b_hex(bytes(hexstring.replace(" ", ""), default_encoding))
     raise TypeError('argument shall be bytes or string type')
 
 
 def bytes2hex(byte_string):
     s = b2a_hex(byte_string)
-    if not in_py2:
-        s = s.decode()
+    s = s.decode()
     return " ".join(s[i:i + 2] for i in range(0, len(s), 2))
