@@ -46,18 +46,13 @@ Based on Rickard Holmberg's docbook_to_dict2013.py.
 
 import os
 import xml.etree.ElementTree as ET
-
-try:
-    import urllib2
-    # python2
-
-except ImportError:
-    import urllib.request as urllib2
-    # python3
+import urllib.request as urllib2
 
 
 _DIRECTORY = os.path.dirname(__file__)
-PYDICOM_DICT_FILENAME = os.path.join(_DIRECTORY, '../../pydicom/_dicom_dict.py')
+PYDICOM_DICT_FILENAME = os.path.join(
+    _DIRECTORY, '../../pydicom/_dicom_dict.py'
+)
 MAIN_DICT_NAME = 'DicomDictionary'
 MASK_DICT_NAME = 'RepeatersDictionary'
 
@@ -299,7 +294,6 @@ py_file = open(PYDICOM_DICT_FILENAME, "w")
 FILE_DOCSTRING = '"""DICOM data dictionary auto-generated by %s"""\n' \
                                                 % os.path.basename(__file__)
 py_file.write(FILE_DOCSTRING)
-py_file.write('from __future__ import absolute_import\n\n')
 py_file.write('# Each dict entry is Tag : (VR, VM, Name, Retired, Keyword)')
 write_dict(py_file, MAIN_DICT_NAME,
            main_attributes, tag_is_string=False)
